@@ -1,11 +1,26 @@
 require 'json'
 require 'chef_zero/endpoints/rest_object_endpoint'
-require 'chef_zero/data_normalizer'
+require 'chef_zero/chef_data/data_normalizer'
 
 module ChefZero
   module Endpoints
-    # /clients/* and /users/*
+    # /organizations/ORG/clients/NAME
+    # /organizations/ORG/users/NAME
+    # /users/NAME
     class ActorEndpoint < RestObjectEndpoint
+      def delete(request)
+        result = super
+        if request.rest_path[0] == 'users'
+          list_data(request, [ 'organizations' ]).each do |org|
+            begin
+              delete_data(request, [ 'organizations', org, 'users', request.rest_path[1] ], :data_store_exceptions)
+            rescue DataStore::DataNotFoundError
+            end
+          end
+        end
+        result
+      end
+
       def put(request)
         # Find out if we're updating the public key.
         request_body = JSON.parse(request.body, :create_additions => false)
@@ -37,17 +52,23 @@ module ChefZero
         result = super(request)
 
         # Inject private_key into response, delete public_key/password if applicable
-        if result[0] == 200
-          response = JSON.parse(result[2], :create_additions => false)
-          response['private_key'] = private_key if private_key
-          response.delete('public_key') if !updating_public_key && request.rest_path[0] == 'users'
-          response.delete('password')
-          # For PUT /clients, a rename returns 201.
-          if request_body['name'] && request.rest_path[1] != request_body['name']
-            json_response(201, response)
+        if result[0] == 200 || result[0] == 201
+          if request.rest_path[0] == 'users'
+            key = nil
+            identity_keys.each do |identity_key|
+              key ||= request_body[identity_key]
+            end
+            key ||= request.rest_path[-1]
+            response = {
+              'uri' => build_uri(request.base_uri, [ 'users', key ])
+            }
           else
-            json_response(200, response)
+            response = JSON.parse(result[2], :create_additions => false)
           end
+          response['private_key'] = private_key if private_key
+          response.delete('public_key') if !updating_public_key && request.rest_path[2] == 'users'
+          response.delete('password')
+          json_response(result[0], response)
         else
           result
         end
@@ -55,14 +76,13 @@ module ChefZero
 
       def populate_defaults(request, response_json)
         response = JSON.parse(response_json, :create_additions => false)
-        if request.rest_path[0] == 'clients'
-          response = DataNormalizer.normalize_client(response, request.rest_path[1])
+        if request.rest_path[2] == 'clients'
+          response = ChefData::DataNormalizer.normalize_client(response, request.rest_path[3])
         else
-          response = DataNormalizer.normalize_user(response, request.rest_path[1])
+          response = ChefData::DataNormalizer.normalize_user(response, request.rest_path[3], identity_keys, server.options[:osc_compat], request.method)
         end
         JSON.pretty_generate(response)
       end
     end
   end
 end
-
