@@ -12,10 +12,11 @@ module ChefZero
       end
 
       def post(request)
-        key = JSON.parse(request.body, :create_additions => false)[identity_key]
+        json = JSON.parse(request.body, :create_additions => false)
+        key = identity_keys.map { |k| json[k] }.select { |v| v }.first
         response = super(request)
         if response[0] == 201
-          already_json_response(201, DataBagItemEndpoint::populate_defaults(request, request.body, request.rest_path[1], key))
+          already_json_response(201, DataBagItemEndpoint::populate_defaults(request, request.body, request.rest_path[3], key))
         else
           response
         end
@@ -31,7 +32,7 @@ module ChefZero
       end
 
       def delete(request)
-        key = request.rest_path[1]
+        key = request.rest_path[3]
         delete_data_dir(request, request.rest_path, :recursive)
         json_response(200, {
           'chef_type' => 'data_bag',
@@ -42,4 +43,3 @@ module ChefZero
     end
   end
 end
-
