@@ -1,6 +1,6 @@
 require 'json'
 require 'chef_zero/endpoints/rest_object_endpoint'
-require 'chef_zero/data_normalizer'
+require 'chef_zero/chef_data/data_normalizer'
 
 module ChefZero
   module Endpoints
@@ -8,7 +8,7 @@ module ChefZero
     class NodeEndpoint < RestObjectEndpoint
       def populate_defaults(request, response_json)
         node = JSON.parse(response_json, :create_additions => false)
-        node = DataNormalizer.normalize_node(node, request.rest_path[1])
+        node = ChefData::DataNormalizer.normalize_node(node, request.rest_path[3])
         JSON.pretty_generate(node)
       end
     end
