@@ -2,22 +2,32 @@ require 'rack/request'
 
 module ChefZero
   class RestRequest
-    def initialize(env)
+    def initialize(env, rest_base_prefix = [])
       @env = env
+      @rest_base_prefix = rest_base_prefix
     end
 
     attr_reader :env
+    attr_accessor :rest_base_prefix
 
     def base_uri
       @base_uri ||= "#{env['rack.url_scheme']}://#{env['HTTP_HOST']}#{env['SCRIPT_NAME']}"
     end
 
+    def base_uri=(value)
+      @base_uri = value
+    end
+
+    def requestor
+      @env['HTTP_X_OPS_USERID']
+    end
+
     def method
       @env['REQUEST_METHOD']
     end
 
     def rest_path
-      @rest_path ||= env['PATH_INFO'].split('/').select { |part| part != "" }
+      @rest_path ||= rest_base_prefix + env['PATH_INFO'].split('/').select { |part| part != "" }
     end
 
     def body=(body)
@@ -53,4 +63,3 @@ module ChefZero
     end
   end
 end
-
